<?php

namespace Conotoxia\Pay\Helper;

use Magento\Framework\App\Helper\AbstractHelper;
use Conotoxia\Pay\Api\Definitions;
use Magento\Framework\App\Helper\Context;
use Magento\Framework\View\Asset\Repository;

class AssetHelper extends AbstractHelper
{
    private Repository $assetRepository;

    public function __construct(Context $context, Repository $assetRepository)
    {
        $this->assetRepository = $assetRepository;
        parent::__construct($context);
    }

    /**
     * Returns the conotoxia pay logo url
     * @return string
     */
    public function getConotoxiaPayLogo(): string {
        return $this->assetRepository->getUrl(Definitions::CONOTOXIA_PAY_LOGO);
    }

    /**
     * Returns an array of urls to enabled payment method icons.
     * @return array
     */
    public function getPaymentMethodIcons(): array {
        $paymentMethods = $this->scopeConfig->getValue(Definitions::ICONS);
        $paymentMethodIcons = [];
        if (isset($paymentMethods) && is_array($paymentMethods)) {
            foreach ($paymentMethods as $paymentMethod => $isActive) {
                if ($isActive) {
                    $fileId = 'Conotoxia_Pay::images/' . $paymentMethod . '.svg';
                    $iconUrl = $this->assetRepository->getUrl($fileId);
                    array_push($paymentMethodIcons, $iconUrl);
                }
            }
        }
        return $paymentMethodIcons;
    }
}